
import { stringify } from 'qs';
import {
  queryCampusList,
  queryTerminalsList,
  queryCampusAmount,
  queryTerminalsAmount,
  queryTotalList,
} from '../services/accounts';

export default {
  namespace: 'accounts',
  state: {
    list: [],
    pageNo: 1,
    pageSize: 15,
    totalSize: 0,
    campusAmount: 0,
    currentItem: {},
  },
  effects: {
    *fetchCampusList({ payload }, { call, put }) {
      const response = yield call(queryCampusList, payload);
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchTerminalsList({ payload }, { call, put }) {
      const response = yield call(queryTerminalsList, payload);
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchCampusAmount({ payload }, { call, put }) {
      const response = yield call(queryCampusAmount, payload);
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            campusAmount: response.data,
          },
        });
      }
    },
    *fetchTerminalsAmount({ payload }, { call, put }) {
      const response = yield call(queryTerminalsAmount, payload);
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            terminalsAmount: response.data,
          },
        });
      }
    },
    *fetchTotalList({ payload }, { call, put }) {
      const response = yield call(queryTotalList, payload);
      if (response.success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: response.data.list || [],
            pageSize: response.data.pageSize,
            totalSize: response.data.totalSize,
            pageNo: response.data.pageNo,
          },
        });
      }
    },
    *fetchCampusExcel({ payload }, { call }) {
      const url = '/api/stmt/campus/export';
      window.location.href = url;
    },
    *fetchTerminalsExcel({ payload }, { call }) {
      const url = '/api/stmt/terminal/user/export';
      window.location.href = url;
    },
    *fetchOverdueExcel({ payload }, { call }) {
      const url = '/api/stmt/terminal/user/export?fastExpired=1';
      window.location.href = url;
    },
  },

  reducers: {
    querySuccess(state, action) {
      return {
        ...state,
        ...action.payload,
      };
    },
  },

};
